import React, { FC, useContext, useState } from 'react'
import { TextInput, Legend } from '../../ui/form'
import AccordionContext from '../../ui/accordion/AccordionContext';

import { tips } from '../locales'
import storage from '../utils/storage'
import './styles.scss'

const PO_NUMBER = 'b3-po-number'

const PoNumber:FC = () => {
  const { selectedItemId } = useContext(AccordionContext);
  const [poNumber, setPoNumber] = useState(storage.B3PoNumber.getValue() || '')
  const isSelected = selectedItemId === 'cheque'

  const handleInputChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const val = e.target.value
    setPoNumber(val)
    val ? storage.B3PoNumber.setValue(val) : storage.B3PoNumber.removeValue()
  }

  return (
    <div className="b3-po-container" >
      <Legend className={isSelected ? 'inner-po-label': ''}>
        <label htmlFor={PO_NUMBER}>
          <span>{tips['b3.poNumber.label']} </span>
          {
             !isSelected && (<span>{tips['b3.label.optional']}</span>)
          }
        </label>
      </Legend>  
      <TextInput 
        name={PO_NUMBER}
        value={poNumber}
        onChange={handleInputChange}
      />
    </div>
  )
}

export default PoNumber